PostProcessor class

Implementers

Constructors

PostProcessor(Map<String, dynamic> config)

Properties

config Map<String, dynamic>
The configuration for the post-processor.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(List<String>? tokens, [List<String>? tokens2, bool? add_special_tokens]) PostProcessedOutput
Alias for {@link PostProcessor#post_process}. @param {Array} tokens The text or array of texts to post-process. @param {...*} args Additional arguments required by the post-processing logic. @returns {PostProcessedOutput} The post-processed tokens.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post_process(List<String>? tokens, [List<String>? tokens2, bool? add_special_tokens]) PostProcessedOutput
Method to be implemented in subclass to apply post-processing on the given tokens.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromConfig(Map<String, dynamic>? config) PostProcessor?
Factory method to create a PostProcessor object from a configuration object.