remove_space property
Whether or not to strip the text when tokenizing (removing excess spaces before and after the string).
Implementation
bool? remove_space;
Whether or not to strip the text when tokenizing (removing excess spaces before and after the string).
bool? remove_space;