PostProcessor class
Properties
config
↔ Map <String , dynamic >
The configuration for the post-processor.
getter/setter pair
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
call (List <String > ? tokens , [List <String > ? tokens2 , bool ? add_special_tokens ])
→ PostProcessedOutput
Alias for {@link PostProcessor#post_process}.
@param {Array} tokens The text or array of texts to post-process.
@param {...*} args Additional arguments required by the post-processing logic.
@returns {PostProcessedOutput} The post-processed tokens.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post_process (List <String > ? tokens , [List <String > ? tokens2 , bool ? add_special_tokens ])
→ PostProcessedOutput
Method to be implemented in subclass to apply post-processing on the given tokens.
toString ()
→ String
A string representation of this object.
inherited